pub struct Cli {Show 14 fields
pub ask: bool,
pub stage: bool,
pub max: Option<usize>,
pub model: Option<String>,
pub api_key: Option<String>,
pub provider: Option<String>,
pub url: Option<String>,
pub diff: Option<String>,
pub branch: Option<String>,
pub no_stream: bool,
pub verbose: u8,
pub config: Option<String>,
pub command: Option<Command>,
pub version: bool,
}Expand description
CLI options
Fields
ask: boolInteractive mode: classify each file and do per-file summaries
stage: boolStage all changes before generating the commit message
max: Option<usize>Max concurrent requests to the LLM API
model: Option<String>Model name to use (e.g. gpt-4o-mini)
api_key: Option<String>API key (otherwise uses OPENAI_API_KEY env var)
provider: Option<String>LLM provider / API style (openai or ollama)
url: Option<String>Base URL for the selected provider (e.g. http://localhost:11434) llama3.1:8b-instruct-q5_K_M
diff: Option<String>Read diff from a file instead of git staged changes (use “-” for stdin). Cannot be used with –ask mode.
branch: Option<String>Branch name to use in the commit message context (used with –diff). If not specified when using –diff, defaults to the current branch.
no_stream: boolDisable streaming responses (streaming is on by default)
verbose: u8Increase verbosity (-v, -vv, -vvv)
config: Option<String>Define config file (default: ~/.config/commitbot.toml)
command: Option<Command>Subcommand (e.g. ‘pr’)
version: boolPrint only the version number (e.g. “0.5.1”). This replaces clap’s auto –version output.